Challenge resource models for the Circle User-Controlled Wallets API.
Contains request parameters and response types for PIN challenge and security question endpoints, as well as the challenge-ID response used by most write operations.
Structs
- Challenge
- A challenge record returned by the Circle API.
- Challenge
Data datapayload wrapping a single challenge.- Challenge
IdData datapayload returned by most write operations.- Challenge
IdResponse - Response envelope for operations that return a challenge ID.
- Challenge
Response - Response envelope for a single challenge lookup.
- Challenges
- Response envelope for list-challenges.
- Challenges
Data datapayload wrapping a list of challenges.- SetPin
AndInit Wallet Request - Request body for
initializeUser(sets PIN and optionally creates wallets). - SetPin
Request - Request body for PIN set/change/restore operations.
Enums
- Challenge
Status - Status of a challenge.
- Challenge
Type - Type of a PIN or device challenge.