Module common

Module common 

Common types shared across the User-Controlled Wallets API.

Includes shared pagination, blockchain, error, and identifier types used across user-controlled wallet endpoints.

Structs

ApiErrorBody
API error response body returned by Circle on non-2xx responses.
PageParams
Query parameters for paginated list endpoints.
TransactionFee
Detailed fee break-down for a transaction.

Enums

AccountType
Wallet account type.
Blockchain
Blockchain network identifier used throughout the Circle API.
CustodyType
Custody type for a wallet.
FeeLevel
Gas fee level preference for a transaction.
ScaCore
Smart Contract Account core version.
TokenStandard
Token standard identifier.
WalletState
Operational state of a wallet.