Module signing

Module signing 

Signing resource models for the Circle User-Controlled Wallets API.

Contains request types for message and transaction signing endpoints. All signing responses return a challengeId — the actual signing is completed on the client side via the Circle Web3 Services mobile SDK.

Structs

SignMessageRequest
Request body for signMessage.
SignTransactionRequest
Request body for signTransaction.
SignTypedDataRequest
Request body for signTypedData.