Common types shared across the User-Controlled Wallets API.
Includes shared pagination, blockchain, error, and identifier types used across user-controlled wallet endpoints.
Structs
- ApiError
Body - API error response body returned by Circle on non-2xx responses.
- Page
Params - Query parameters for paginated list endpoints.
- Transaction
Fee - Detailed fee break-down for a transaction.
Enums
- Account
Type - Wallet account type.
- Blockchain
- Blockchain network identifier used throughout the Circle API.
- Custody
Type - Custody type for a wallet.
- FeeLevel
- Gas fee level preference for a transaction.
- ScaCore
- Smart Contract Account core version.
- Token
Standard - Token standard identifier.
- Wallet
State - Operational state of a wallet.